@@ -27,6 +27,7 @@ from urllib3.util.url import parse_url
 
 from semantic_release import hvcs
 from semantic_release.changelog import environment
+from semantic_release.changelog.context import ChangelogMode
 from semantic_release.cli.const import DEFAULT_CONFIG_FILE
 from semantic_release.cli.masking_filter import MaskingFilter
 from semantic_release.commit_parser import (
@@ -94,6 +95,14 @@ class EnvConfigVar(BaseModel):
 MaybeFromEnv = Union[EnvConfigVar, str]
 
 
+class ChangelogOutputFormat(str, Enum):
+    """Supported changelog output formats when using the default templates."""
+
+    MARKDOWN = "md"
+    RESTRUCTURED_TEXT = "rst"
+    NONE = ""
+
+
 class ChangelogEnvironmentConfig(BaseModel):
     block_start_string: str = "{%"
     block_end_string: str = "%}"
@@ -108,14 +117,100 @@ class ChangelogEnvironmentConfig(BaseModel):
     newline_sequence: Literal["\n", "\r", "\r\n"] = "\n"
     keep_trailing_newline: bool = False
     extensions: Tuple[str, ...] = ()
-    autoescape: Union[bool, str] = True
+    autoescape: Union[bool, str] = False
+
+
+class DefaultChangelogTemplatesConfig(BaseModel):
+    changelog_file: str = "CHANGELOG.md"
+    output_format: ChangelogOutputFormat = ChangelogOutputFormat.NONE
+
+    @model_validator(mode="after")
+    def interpret_output_format(self) -> Self:
+        # Set the output format value when no user input is given
+        if self.output_format == ChangelogOutputFormat.NONE:
+            try:
+                # Note: If the user gave no extension, force '.' so enumeration fails,
+                # and defaults to markdown
+                # Otherwise normal files with extensions will just look for the extension support
+                self.output_format = ChangelogOutputFormat(
+                    Path(self.changelog_file).suffix.lstrip(".") or "."
+                )
+            except ValueError:
+                self.output_format = ChangelogOutputFormat.MARKDOWN
+
+        return self
 
 
 class ChangelogConfig(BaseModel):
-    template_dir: str = "templates"
-    changelog_file: str = "CHANGELOG.md"
-    exclude_commit_patterns: Tuple[str, ...] = ()
+    # TODO: BREAKING CHANGE v10, move to DefaultChangelogTemplatesConfig
+    changelog_file: str = ""
+    """Deprecated! Moved to 'default_templates.changelog_file'"""
+
+    default_templates: DefaultChangelogTemplatesConfig = (
+        DefaultChangelogTemplatesConfig(output_format=ChangelogOutputFormat.NONE)
+    )
     environment: ChangelogEnvironmentConfig = ChangelogEnvironmentConfig()
+    exclude_commit_patterns: Tuple[str, ...] = ()
+    mode: ChangelogMode = ChangelogMode.INIT
+    insertion_flag: str = ""
+    template_dir: str = "templates"
+
+    @field_validator("changelog_file", mode="after")
+    @classmethod
+    def changelog_file_deprecation_warning(cls, val: str) -> str:
+        log.warning(
+            str.join(
+                " ",
+                [
+                    "The 'changelog.changelog_file' configuration option is moving to 'changelog.default_templates.changelog_file'.",
+                    "Please update your configuration as the compatibility will break in v10.",
+                ],
+            )
+        )
+        return val
+
+    @model_validator(mode="after")
+    def move_changelog_file(self) -> Self:
+        # TODO: Remove this method in v10
+        if not self.changelog_file:
+            return self
+
+        if self.changelog_file == self.default_templates.changelog_file:
+            return self
+
+        # Re-evaluate now that we are passing the changelog_file option down to default_templates
+        # and only reset the output_format if it was not already set by the user
+        self.default_templates = DefaultChangelogTemplatesConfig.model_validate(
+            {
+                **self.default_templates.model_dump(),
+                "changelog_file": self.changelog_file,
+                "output_format": (
+                    self.default_templates.output_format
+                    if self.default_templates.output_format
+                    != ChangelogOutputFormat.MARKDOWN
+                    else ChangelogOutputFormat.NONE
+                ),
+            }
+        )
+
+        return self
+
+    @model_validator(mode="after")
+    def load_default_insertion_flag_on_missing(self) -> Self:
+        # Set the insertion flag value when no user input is given
+        if not self.insertion_flag:
+            defaults = {
+                ChangelogOutputFormat.MARKDOWN: "<!-- version list -->",
+                ChangelogOutputFormat.RESTRUCTURED_TEXT: f"..{os.linesep}    version list",
+            }
+            try:
+                self.insertion_flag = defaults[self.default_templates.output_format]
+            except KeyError as err:
+                raise ValueError(
+                    "changelog.default_templates.output_format cannot be None"
+                ) from err
+
+        return self
 
 
 class BranchConfig(BaseModel):
@@ -123,6 +218,19 @@ class BranchConfig(BaseModel):
     prerelease_token: str = "rc"  # noqa: S105
     prerelease: bool = False
 
+    @field_validator("match", mode="after")
+    @classmethod
+    def validate_match(cls, match: str) -> str:
+        # Allow the special case of a plain wildcard although it's not a valid regex
+        if match == "*":
+            return ".*"
+
+        try:
+            re.compile(match)
+        except re.error as err:
+            raise ValueError(f"Invalid regex {match!r}") from err
+        return match
+
 
 class RemoteConfig(BaseModel):
     name: str = "origin"
@@ -386,7 +494,11 @@ class RuntimeContext:
     changelog_excluded_commit_patterns: Tuple[re.Pattern[str], ...]
     version_declarations: Tuple[VersionDeclarationABC, ...]
     hvcs_client: hvcs.HvcsBase
+    changelog_insertion_flag: str
+    changelog_mode: ChangelogMode
     changelog_file: Path
+    changelog_style: str
+    changelog_output_format: ChangelogOutputFormat
     ignore_token_for_push: bool
     template_environment: Environment
     template_dir: Path
@@ -540,7 +652,18 @@ class RuntimeContext:
             try:
                 path, variable = decl.split(":", maxsplit=1)
                 # VersionDeclarationABC handles path existence check
-                search_text = rf"(?x){variable}\s*(:=|[:=])\s*(?P<quote>['\"])(?P<version>{SEMVER_REGEX.pattern})(?P=quote)"  # noqa: E501
+                search_text = str.join(
+                    "",
+                    [
+                        # Supports optional matching quotations around variable name
+                        # Negative lookbehind to ensure we don't match part of a variable name
+                        f"""(?x)(?P<quote1>['"])?(?<![\\w.-]){variable}(?P=quote1)?""",
+                        # Supports walrus, equals sign, or colon as assignment operator ignoring whitespace separation
+                        r"\s*(:=|[:=])\s*",
+                        # Supports optional matching quotations around version number of a SEMVER pattern
+                        f"""(?P<quote2>['"])?(?P<version>{SEMVER_REGEX.pattern})(?P=quote2)?""",
+                    ],
+                )
                 pd = PatternVersionDeclaration(path, search_text)
             except ValueError as exc:
                 log.exception("Invalid variable declaration %r", decl)
@@ -572,7 +695,10 @@ class RuntimeContext:
         # which means it returns a relative path. So we force absolute to ensure path is complete
         # for the next check of path matching
         changelog_file = (
-            Path(raw.changelog.changelog_file).expanduser().resolve().absolute()
+            Path(raw.changelog.default_templates.changelog_file)
+            .expanduser()
+            .resolve()
+            .absolute()
         )
 
         # Prevent path traversal attacks
@@ -629,6 +755,18 @@ class RuntimeContext:
 
             build_cmd_env[name] = env_val
 
+        # TODO: better support for custom parsers that actually just extend defaults
+        #
+        # Here we just assume the desired changelog style matches the parser name
+        # as we provide templates specific to each parser type. Unfortunately if the user has
+        # provided a custom parser, it would be up to the user to provide custom templates
+        # but we just assume the base template is angular
+        # changelog_style = (
+        #     raw.commit_parser
+        #     if raw.commit_parser in _known_commit_parsers
+        #     else "angular"
+        # )
+
         self = cls(
             repo_dir=raw.repo_dir,
             commit_parser=commit_parser,
@@ -640,10 +778,16 @@ class RuntimeContext:
             version_declarations=tuple(version_declarations),
             hvcs_client=hvcs_client,
             changelog_file=changelog_file,
+            changelog_mode=raw.changelog.mode,
+            changelog_insertion_flag=raw.changelog.insertion_flag,
             assets=raw.assets,
             commit_author=commit_author,
             commit_message=raw.commit_message,
             changelog_excluded_commit_patterns=changelog_excluded_commit_patterns,
+            # TODO: change when we have other styles per parser
+            # changelog_style=changelog_style,
+            changelog_style="angular",
+            changelog_output_format=raw.changelog.default_templates.output_format,
             prerelease=branch_config.prerelease,
             ignore_token_for_push=raw.remote.ignore_token_for_push,
             template_dir=template_dir,
