@@ -6,7 +6,9 @@ from typing import TYPE_CHECKING
 import pytest
 from git import Repo
 
-from tests.const import EXAMPLE_HVCS_DOMAIN
+from semantic_release.cli.config import ChangelogOutputFormat
+
+from tests.const import EXAMPLE_HVCS_DOMAIN, NULL_HEX_SHA
 from tests.util import copy_dir_tree, temporary_working_directory
 
 if TYPE_CHECKING:
@@ -62,28 +64,40 @@ def get_commits_for_trunk_only_repo_w_no_tags() -> GetRepoDefinitionFn:
             },
             "commits": [
                 {
-                    "angular": "Initial commit",
-                    "emoji": "Initial commit",
-                    "scipy": "Initial commit",
-                    "tag": "Initial commit",
+                    "angular": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
+                    "emoji": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
+                    "scipy": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
+                    "tag": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
                 },
                 {
-                    "angular": "fix: add some more text",
-                    "emoji": ":bug: add some more text",
-                    "scipy": "MAINT: add some more text",
-                    "tag": ":nut_and_bolt: add some more text",
+                    "angular": {"msg": "fix: correct some text", "sha": NULL_HEX_SHA},
+                    "emoji": {"msg": ":bug: correct some text", "sha": NULL_HEX_SHA},
+                    "scipy": {"msg": "MAINT: correct some text", "sha": NULL_HEX_SHA},
+                    "tag": {
+                        "msg": ":nut_and_bolt: correct some text",
+                        "sha": NULL_HEX_SHA,
+                    },
                 },
                 {
-                    "angular": "feat: add much more text",
-                    "emoji": ":sparkles: add much more text",
-                    "scipy": "ENH: add much more text",
-                    "tag": ":sparkles: add much more text",
+                    "angular": {"msg": "feat: add much more text", "sha": NULL_HEX_SHA},
+                    "emoji": {
+                        "msg": ":sparkles: add much more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {"msg": "ENH: add much more text", "sha": NULL_HEX_SHA},
+                    "tag": {
+                        "msg": ":sparkles: add much more text",
+                        "sha": NULL_HEX_SHA,
+                    },
                 },
                 {
-                    "angular": "fix: more text",
-                    "emoji": ":bug: more text",
-                    "scipy": "MAINT: more text",
-                    "tag": ":nut_and_bolt: more text",
+                    "angular": {"msg": "fix: correct some text", "sha": NULL_HEX_SHA},
+                    "emoji": {"msg": ":bug: correct some text", "sha": NULL_HEX_SHA},
+                    "scipy": {"msg": "MAINT: correct some text", "sha": NULL_HEX_SHA},
+                    "tag": {
+                        "msg": ":nut_and_bolt: correct some text",
+                        "sha": NULL_HEX_SHA,
+                    },
                 },
             ],
         },
@@ -102,7 +116,7 @@ def get_commits_for_trunk_only_repo_w_no_tags() -> GetRepoDefinitionFn:
                 ),
                 "commits": [
                     # Extract the correct commit message for the commit type
-                    message_variants[commit_type]
+                    deepcopy(message_variants[commit_type])
                     for message_variants in version_def["commits"]
                 ],
             }
@@ -127,6 +141,7 @@ def build_trunk_only_repo_w_no_tags(
     get_commits_for_trunk_only_repo_w_no_tags: GetRepoDefinitionFn,
     build_configured_base_repo: BuildRepoFn,
     changelog_md_file: Path,
+    changelog_rst_file: Path,
     simulate_change_commits_n_rtn_changelog_entry: SimulateChangeCommitsNReturnChangelogEntryFn,
     simulate_default_changelog_creation: SimulateDefaultChangelogCreationFn,
 ) -> BuildRepoFn:
@@ -155,13 +170,24 @@ def build_trunk_only_repo_w_no_tags(
         with temporary_working_directory(repo_dir), Repo(".") as git_repo:
             # Run set up commits
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write expected changelog (should match template changelog)
+            # write expected Markdown changelog
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
         return repo_dir, hvcs
